
# Installation Guide for Developers

# GitHub

Before starting, make sure you have a _fork_ of the `cgse` repository. Through this fork (which 
resides on the GitHub  server) you will create pull requests. Install a clone of your fork on 
your local machine or laptop.

![img.png](../images/github-fork-clone.png#only-light)
![img.png](../images/github-fork-clone-dark.png#only-dark)


TBW
